"""This module has functions which take a snapshot of the Python
environment's dependencies.
"""

__version__ = "$Revision: 1.3 $"
__author__ = "Peter Hendrickson <pdh@wiredyne.com>"

# License:  This code is in the public domain.  Any of this code may be
#           freely reproduced or adapted, even without mentioning the
#           source.

# Warranty: IN NO EVENT SHALL THE AUTHOR BE LIABLE TO ANY PARTY FOR
#           DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL
#           DAMAGES ARISING OUT OF THE USE OF THIS CODE, EVEN IF THE
#           AUTHOR HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
#           THE AUTHOR SPECIFICALLY DISCLAIMS ANY WARRANTIES,
#           INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#           MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE
#           CODE PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THERE
#           IS NO OBLIGATION WHATSOEVER TO PROVIDE MAINTENANCE,
#           SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.

# Built in anyway - won't contaminate the dependencies.
import sys

def python_depends(include_this_module=False, include_calling_program=False):
    """Return sorted list of files upon which python modules depend.

    By default, the module where this function appears is not
    included.  This can be overridden by setting include_this_module
    to True.

    Also by default, the file containing the calling program is not
    included.  This can be overridden by setting
    include_calling_program to True.
    """

    python_depends_dict = {}
    for modname in sys.modules.keys():
        if sys.modules[modname] is not None:
            if sys.modules[modname].__dict__.has_key('__file__'):
                file = sys.modules[modname].__file__
                if modname == __name__:
                    if include_this_module:
                        python_depends_dict[file] = 1
                elif modname == '__main__':
                    if include_calling_program:
                        python_depends_dict[file] = 1
                else:
                    python_depends_dict[file] = 1
    python_depends_list = python_depends_dict.keys()
    python_depends_list.sort()
    return python_depends_list
