#!/usr/bin/env python

# usage: chroot-build.py newroot config-file script-file

__version__ = "$Revision: 1.3 $"
__author__ = "Peter Hendrickson <pdh@wiredyne.com>"

# License:  This code is in the public domain.  Any of this code may be
#           freely reproduced or adapted, even without mentioning the
#           source.

# Warranty: IN NO EVENT SHALL THE AUTHOR BE LIABLE TO ANY PARTY FOR
#           DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL
#           DAMAGES ARISING OUT OF THE USE OF THIS CODE, EVEN IF THE
#           AUTHOR HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
#           THE AUTHOR SPECIFICALLY DISCLAIMS ANY WARRANTIES,
#           INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#           MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE
#           CODE PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THERE
#           IS NO OBLIGATION WHATSOEVER TO PROVIDE MAINTENANCE,
#           SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.

# Emits an sh script which will build a chroot tree rooted at newroot.
# config-file should be a list of files, links, and directories
# desired, one per line.  Comment lines begin with a '#' character.
# The result is put in script-file.  If script-file already exists, it
# is not overwritten.

import fileinput
import os.path
import re
import sys
import ChrootBuilder

comment = re.compile(r'^\s*#.*$')

def main():
    if len(sys.argv) != 4:
        print "usage: %s newroot config-file script-file" % (sys.argv[0])
    newroot = sys.argv[1]
    config = sys.argv[2]
    script = sys.argv[3]
    model = ChrootBuilder.ChrootModel(newroot)
    infile = open(config, "r")
    line = infile.readline()
    while line:
        if not comment.search(line):
            if line[-1] == '\n':
                line = line[0:-1]
            line.strip()
            model.add_files(line)
        line = infile.readline()
    model.process()
    if os.path.exists(script):
        print >> sys.stderr, "%s already exists.  Won't overwrite." % (script)
        sys.exit(1)
    outfile = open(script, "w")
    print >> outfile, "#!/bin/sh"
    print >> outfile, ""
    print >> outfile, model.script()

main()
