#!/usr/bin/env python

# usage: chroot-simple-http.py newroot script-file

__version__ = "$Revision: 1.4 $"
__author__ = "Peter Hendrickson <pdh@wiredyne.com>"

# License:  This code is in the public domain.  Any of this code may be
#           freely reproduced or adapted, even without mentioning the
#           source.

# Warranty: IN NO EVENT SHALL THE AUTHOR BE LIABLE TO ANY PARTY FOR
#           DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL
#           DAMAGES ARISING OUT OF THE USE OF THIS CODE, EVEN IF THE
#           AUTHOR HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
#           THE AUTHOR SPECIFICALLY DISCLAIMS ANY WARRANTIES,
#           INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#           MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE
#           CODE PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THERE
#           IS NO OBLIGATION WHATSOEVER TO PROVIDE MAINTENANCE,
#           SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.

# Emits a script which builds an sh script which in turn sets up a
# directory hierarchy which can run the Python SimpleHTTPServer.

# This command will run the server if var/www (in the chrooted jail)
# has been created and populated with files to serve:
# env -i PATH=/bin:/usr/local/bin /usr/sbin/chroot -u simphttp -g simphttp /usr/var/chroot/simphttp /usr/local/bin/python -c "import SimpleHTTPServer; import os; os.chdir('/var/www'); SimpleHTTPServer.test()" 8080

import SimpleHTTPServer;

# Take a snapshot of the dependencies.
import PythonDepends
raw_py_depends = PythonDepends.python_depends()

# With snapshot taken, we can load whatever we like.
from ChrootBuilder import *
import sys
import os.path

def main():
    if len(sys.argv) != 3:
        print >> sys.stderr, "usage: %s newroot script-file" % (sys.argv[0])
        sys.exit(1)
    newroot = sys.argv[1]
    script = sys.argv[2]
    model = ChrootModel(newroot)
    py_depends = [os.path.abspath(file) for file in raw_py_depends]
    py_depends.sort()
    model.add_files(*py_depends)
    # Python complains if it doesn't have its lib-dynload directory,
    # even if nothing is in it.
    lib_dynload_dir = sys.exec_prefix + '/lib/python' + sys.version[0:3] \
                      + '/lib-dynload'
    model.add_files(lib_dynload_dir)
    # Need Python binary and shared object support library.
    model.add_files("/usr/libexec/ld.elf_so",
                    "/usr/local/bin/python")
    model.process()
    if os.path.exists(script):
        print >> sys.stderr, "%s already exists.  Won't overwrite." % (script)
        sys.exit(1)
    outfile = open(script, "w")
    print >> outfile, "#!/bin/sh"
    print >> outfile, ""
    print >> outfile, "# Umask which lets other processes see but not modify."
    print >> outfile, "umask 0022"
    print >> outfile, ""
    print >> outfile, model.script(),

main()
